Source code
===========

.. toctree::

pySOT.auxiliary_problems module
-------------------------------

.. automodule:: pySOT.auxiliary_problems
    :members:
    :undoc-members:

pySOT.controller module
-----------------------

.. automodule:: pySOT.controller
    :members:
    :undoc-members:

pySOT.experimental_design module
--------------------------------

.. automodule:: pySOT.experimental_design
    :members:
    :undoc-members:

pySOT.optimization_problems module
----------------------------------

.. automodule:: pySOT.optimization_problems
    :members:
    :undoc-members:

pySOT.strategy module
---------------------

.. automodule:: pySOT.strategy
    :members:
    :undoc-members:

pySOT.surrogate module
----------------------

.. automodule:: pySOT.surrogate
    :members:
    :undoc-members:

pySOT.utils module
------------------

.. automodule:: pySOT.utils
    :members:
    :undoc-members:
